"""Auto-generated __init__.py for command groups."""

__all__ = [
    "captains_orders",
    "communications_officer",
    "droids",
    "engineering_officer",
    "fleet_commander",
    "gitmaster",
    "insterstellar_officer",
    "maintenance_officer",
    "mcars",
    "navigation_officer",
    "number_two",
    "red_buttons",
    "tactical_officer",
]

from . import captains_orders
from . import communications_officer
from . import droids
from . import engineering_officer
from . import fleet_commander
from . import gitmaster
from . import insterstellar_officer
from . import maintenance_officer
from . import mcars
from . import navigation_officer
from . import number_two
from . import red_buttons
from . import tactical_officer
