#!/usr/bin/env python3
"""
AUTO-GENERATED FILE – DO NOT EDIT MANUALLY.
This file is generated by the sync2_aliases.py tool.
It contains all dynamic imports, group themes/icons, and group help registration code.
"""

# [AUTO-GENERATED COMMAND IMPORTS START]
from starshipagentic.commands.fleet_commander import run_group as fleet_commander
from starshipagentic.commands.number_two import run_group as number_two
from starshipagentic.commands.engineering_officer import run_group as engineering_officer
from starshipagentic.commands.navigation_officer import run_group as navigation_officer
from starshipagentic.commands.communications_officer import run_group as communications_officer
from starshipagentic.commands.insterstellar_officer import run_group as insterstellar_officer
from starshipagentic.commands.captains_orders import run_group as captains_orders
from starshipagentic.commands.tactical_officer import run_group as tactical_officer
from starshipagentic.commands.maintenance_officer import run_group as maintenance_officer
from starshipagentic.commands.red_buttons import run_group as red_buttons
from starshipagentic.commands.gitmaster import run_group as gitmaster
from starshipagentic.commands.mcars import run_group as mcars
from starshipagentic.commands.droids import run_group as droids
from starshipagentic.commands.fleet_commander.tour_ship.cli import tour_ship_command as tour_ship
from starshipagentic.commands.fleet_commander.tour_ship.cli import tour_ship_command as tour
from starshipagentic.commands.fleet_commander.commission_ship.cli import commission_ship_command as commission_ship
from starshipagentic.commands.fleet_commander.commission_ship.cli import commission_ship_command as commission
from starshipagentic.commands.fleet_commander.visualize_ship.cli import visualize_ship_command as visualize_ship
from starshipagentic.commands.number_two.mission_brief.cli import mission_brief_command as mission_brief
from starshipagentic.commands.number_two.mission_brief.cli import mission_brief_command as mission
from starshipagentic.commands.number_two.expand_mission.cli import expand_mission_command as expand_mission
from starshipagentic.commands.number_two.expand_mission.cli import expand_mission_command as expand
from starshipagentic.commands.engineering_officer.review_schematics.cli import review_schematics_command as review_schematics
from starshipagentic.commands.engineering_officer.review_schematics.cli import review_schematics_command as schematics
from starshipagentic.commands.engineering_officer.calibrate_technology.cli import calibrate_technology_command as calibrate_technology
from starshipagentic.commands.engineering_officer.calibrate_technology.cli import calibrate_technology_command as calibrate
from starshipagentic.commands.navigation_officer.plot_navigation.cli import plot_navigation_command as plot_navigation
from starshipagentic.commands.navigation_officer.plot_navigation.cli import plot_navigation_command as navigation
from starshipagentic.commands.navigation_officer.set_waypoints.cli import set_waypoints_command as set_waypoints
from starshipagentic.commands.navigation_officer.set_waypoints.cli import set_waypoints_command as waypoints
from starshipagentic.commands.communications_officer.authorize_codes.cli import authorize_codes_command as authorize_codes
from starshipagentic.commands.communications_officer.authorize_codes.cli import authorize_codes_command as authorize
from starshipagentic.commands.communications_officer.scan_sector.cli import scan_sector_command as scan_sector
from starshipagentic.commands.communications_officer.scan_sector.cli import scan_sector_command as scan
from starshipagentic.commands.communications_officer.receive_transmission.cli import receive_transmission_command as receive_transmission
from starshipagentic.commands.communications_officer.receive_transmission.cli import receive_transmission_command as transmission
from starshipagentic.commands.insterstellar_officer.map_planet.cli import map_planet_command as map_planet
from starshipagentic.commands.insterstellar_officer.map_planet.cli import map_planet_command as map
from starshipagentic.commands.insterstellar_officer.build_landing_zone.cli import build_landing_zone_command as build_landing_zone
from starshipagentic.commands.insterstellar_officer.build_landing_zone.cli import build_landing_zone_command as buildlz
from starshipagentic.commands.insterstellar_officer.fabricate_infrastructure.cli import fabricate_infrastructure_command as fabricate_infrastructure
from starshipagentic.commands.insterstellar_officer.fabricate_infrastructure.cli import fabricate_infrastructure_command as fabricate
from starshipagentic.commands.captains_orders.warp_speed.cli import warp_speed_command as warp_speed
from starshipagentic.commands.captains_orders.warp_speed.cli import warp_speed_command as warp
from starshipagentic.commands.captains_orders.trycoder.cli import trycoder_command as trycoder
from starshipagentic.commands.captains_orders.engage.cli import engage_command as engage
from starshipagentic.commands.tactical_officer.fire_photons.cli import fire_photons_command as fire_photons
from starshipagentic.commands.tactical_officer.fire_photons.cli import fire_photons_command as photons
from starshipagentic.commands.tactical_officer.aim_lasers.cli import aim_lasers_command as aim_lasers
from starshipagentic.commands.tactical_officer.aim_lasers.cli import aim_lasers_command as lasers
from starshipagentic.commands.tactical_officer.shields_up.cli import shields_up_command as shields_up
from starshipagentic.commands.tactical_officer.shields_up.cli import shields_up_command as shields
from starshipagentic.commands.maintenance_officer.create_checkpoint.cli import create_checkpoint_command as create_checkpoint
from starshipagentic.commands.maintenance_officer.create_checkpoint.cli import create_checkpoint_command as checkpoint
from starshipagentic.commands.maintenance_officer.restore_checkpoint.cli import restore_checkpoint_command as restore_checkpoint
from starshipagentic.commands.maintenance_officer.restore_checkpoint.cli import restore_checkpoint_command as restore
from starshipagentic.commands.maintenance_officer.inspect_vessel.cli import inspect_vessel_command as inspect_vessel
from starshipagentic.commands.maintenance_officer.inspect_vessel.cli import inspect_vessel_command as inspect
from starshipagentic.commands.maintenance_officer.complexity_report.cli import complexity_report_command as complexity_report
from starshipagentic.commands.maintenance_officer.complexity_report.cli import complexity_report_command as complexity
from starshipagentic.commands.red_buttons.supernova.cli import supernova_command as supernova
from starshipagentic.commands.gitmaster.teleport.cli import teleport_command as teleport
from starshipagentic.commands.mcars.search.cli import search_command as search
from starshipagentic.commands.mcars.transport.cli import transport_command as transport
from starshipagentic.commands.droids.droid_splain.cli import droid_splain_command as droid_splain
from starshipagentic.commands.droids.droid_splain.cli import droid_splain_command as droid
from starshipagentic.commands.droids.man_splain.cli import man_splain_command as man_splain
from starshipagentic.commands.droids.man_splain.cli import man_splain_command as splain
# [AUTO-GENERATED COMMAND IMPORTS END]


# [AUTO-GENERATED GROUP THEMES AND ICONS START]
GROUP_THEMES = {
    "fleet_commander": "white",
    "number_two": "white",
    "engineering_officer": "white",
    "navigation_officer": "white",
    "communications_officer": "white",
    "insterstellar_officer": "white",
    "captains_orders": "white",
    "tactical_officer": "white",
    "maintenance_officer": "white",
    "red_buttons": "white",
    "gitmaster": "white",
    "mcars": "white",
    "droids": "white",
}

GROUP_ICONS = {
    "fleet_commander": "⚙️",
    "number_two": "⚙️",
    "engineering_officer": "⚙️",
    "navigation_officer": "⚙️",
    "communications_officer": "⚙️",
    "insterstellar_officer": "⚙️",
    "captains_orders": "⚙️",
    "tactical_officer": "⚙️",
    "maintenance_officer": "⚙️",
    "red_buttons": "⚙️",
    "gitmaster": "⚙️",
    "mcars": "⚙️",
    "droids": "⚙️",
}

# [AUTO-GENERATED GROUP THEMES AND ICONS END]


def register_dynamic_groups():
    """Register all dynamic command groups with the main CLI."""
    from starshipagentic.cli import main, enhance_group_help
    import importlib
    GROUP_NAMES = ['fleet_commander', 'number_two', 'engineering_officer', 'navigation_officer', 'communications_officer', 'insterstellar_officer', 'captains_orders', 'tactical_officer', 'maintenance_officer', 'red_buttons', 'gitmaster', 'mcars', 'droids']
    for group in GROUP_NAMES:
        mod = importlib.import_module(f'starshipagentic.commands.{group}')
        group_obj = getattr(mod, f'{group}_group', None)
        if group_obj is None:
            continue
        enhanced = enhance_group_help(group_obj, group)
        main.add_command(enhanced, group)
